"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _utils = require("../../utils");

var _utils2 = require("../utils");

var _default = {
  canProcess: params => {
    const {
      key,
      extension
    } = params;

    if (_utils2.SUPPORTED_IMAGES.includes(extension) === false) {
      return false;
    } // We only want to process original images, and delete all variations of it at once.
    // We DO NOT want to process the event for the deletion of an optimized/transformed image.
    // Unfortunately, there's no way to filter those events on the S3 bucket itself, so we have to do it this way.


    return !(key.startsWith(_utils2.OPTIMIZED_IMAGE_PREFIX) || key.startsWith(_utils2.OPTIMIZED_TRANSFORMED_IMAGE_PREFIX));
  },

  async process({
    s3,
    key,
    extension
  }) {
    // 1. Get optimized image's key.
    await s3.deleteObject((0, _utils.getObjectParams)((0, _utils2.getImageKey)({
      key
    }))).promise(); // 2. Search for all transformed images and delete those too.

    if (_utils2.SUPPORTED_TRANSFORMABLE_IMAGES.includes(extension) === false) {
      return;
    }

    const env = (0, _utils.getEnvironment)();
    const imagesList = await s3.listObjects({
      Bucket: env.bucket,
      Prefix: (0, _utils2.getOptimizedTransformedImageKeyPrefix)(key)
    }).promise();

    if (!imagesList.Contents) {
      return;
    }

    for (const imageObject of imagesList.Contents) {
      if (!imageObject.Key) {
        continue;
      }

      await s3.deleteObject((0, _utils.getObjectParams)(imageObject.Key)).promise();
    }
  }

};
exports.default = _default;