"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.FileStorage = void 0;

var _objectSpread2 = _interopRequireDefault(require("@babel/runtime/helpers/objectSpread2"));

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));

var _error = _interopRequireDefault(require("@webiny/error"));

const storagePluginType = "api-file-manager-storage";

class FileStorage {
  constructor({
    context
  }) {
    (0, _defineProperty2.default)(this, "storagePlugin", void 0);
    (0, _defineProperty2.default)(this, "context", void 0);
    const storagePlugin = context.plugins.byType(storagePluginType).pop();

    if (!storagePlugin) {
      throw new _error.default(`Missing plugin of type "${storagePluginType}".`, "STORAGE_PLUGIN_ERROR");
    }

    this.storagePlugin = storagePlugin;
    this.context = context;
  }

  async upload(params) {
    const settings = await this.context.fileManager.settings.getSettings();

    if (!settings) {
      throw new _error.default("Missing File Manager Settings.", "FILE_MANAGER_ERROR");
    } // Add file to cloud storage.


    const {
      file: fileData
    } = await this.storagePlugin.upload((0, _objectSpread2.default)((0, _objectSpread2.default)({}, params), {}, {
      settings
    }));
    const {
      fileManager
    } = this.context; // Save file in DB.

    return await fileManager.files.createFile((0, _objectSpread2.default)((0, _objectSpread2.default)({}, fileData), {}, {
      meta: {
        private: Boolean(params.hideInFileManager)
      },
      tags: Array.isArray(params.tags) ? params.tags : []
    }));
  }

  async uploadFiles(params) {
    const settings = await this.context.fileManager.settings.getSettings();

    if (!settings) {
      throw new _error.default("Missing File Manager Settings.", "FILE_MANAGER_ERROR");
    } // Upload files to cloud storage.


    const promises = [];

    for (const item of params.files) {
      promises.push(this.storagePlugin.upload((0, _objectSpread2.default)((0, _objectSpread2.default)({}, item), {}, {
        settings
      })));
    } // Wait for all to resolve.


    const uploadFileResponses = await Promise.all(promises);
    const filesData = uploadFileResponses.map(response => response.file);
    const {
      fileManager
    } = this.context; // Save files in DB.

    return fileManager.files.createFilesInBatch(filesData);
  }

  async delete(params) {
    const {
      id,
      key
    } = params;
    const {
      fileManager
    } = this.context; // Delete file from cloud storage.

    await this.storagePlugin.delete({
      key
    }); // Delete file from the DB.

    return await fileManager.files.deleteFile(id);
  }

}

exports.FileStorage = FileStorage;